==> client-java-api-fluent-15.0.1-sources.jar: io/kubernetes/client/openapi/models/V1UserInfoBuilder.java <==
/*
Copyright 2022 The Kubernetes Authors.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;

public class V1UserInfoBuilder extends V1UserInfoFluentImpl<V1UserInfoBuilder>
    implements VisitableBuilder<V1UserInfo, io.kubernetes.client.openapi.models.V1UserInfoBuilder> {
  public V1UserInfoBuilder() {
    this(false);
  }

  public V1UserInfoBuilder(Boolean validationEnabled) {
    this(new V1UserInfo(), validationEnabled);
  }

  public V1UserInfoBuilder(V1UserInfoFluent<?> fluent) {
    this(fluent, false);
  }

  public V1UserInfoBuilder(
      io.kubernetes.client.openapi.models.V1UserInfoFluent<?> fluent,
      java.lang.Boolean validationEnabled) {
    this(fluent, new V1UserInfo(), validationEnabled);
  }

  public V1UserInfoBuilder(
      io.kubernetes.client.openapi.models.V1UserInfoFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1UserInfo instance) {
    this(fluent, instance, false);
  }

  public V1UserInfoBuilder(
      io.kubernetes.client.openapi.models.V1UserInfoFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1UserInfo instance,
      java.lang.Boolean validationEnabled) {
    this.fluent = fluent;
    fluent.withExtra(instance.getExtra());

    fluent.withGroups(instance.getGroups());

    fluent.withUid(instance.getUid());

    fluent.withUsername(instance.getUsername());

    this.validationEnabled = validationEnabled;
  }

  public V1UserInfoBuilder(io.kubernetes.client.openapi.models.V1UserInfo instance) {
    this(instance, false);
  }

  public V1UserInfoBuilder(
      io.kubernetes.client.openapi.models.V1UserInfo instance,
      java.lang.Boolean validationEnabled) {
    this.fluent = this;
    this.withExtra(instance.getExtra());

    this.withGroups(instance.getGroups());

    this.withUid(instance.getUid());

    this.withUsername(instance.getUsername());

    this.validationEnabled = validationEnabled;
  }

  io.kubernetes.client.openapi.models.V1UserInfoFluent<?> fluent;
  java.lang.Boolean validationEnabled;

  public io.kubernetes.client.openapi.models.V1UserInfo build() {
    V1UserInfo buildable = new V1UserInfo();
    buildable.setExtra(fluent.getExtra());
    buildable.setGroups(fluent.getGroups());
    buildable.setUid(fluent.getUid());
    buildable.setUsername(fluent.getUsername());
    return buildable;
  }
}

==> client-java-api-fluent-18.0.1-sources.jar: io/kubernetes/client/openapi/models/V1UserInfoBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Boolean;
public class V1UserInfoBuilder extends V1UserInfoFluentImpl<V1UserInfoBuilder> implements VisitableBuilder<V1UserInfo,V1UserInfoBuilder>{
  public V1UserInfoBuilder() {
    this(false);
  }
  public V1UserInfoBuilder(Boolean validationEnabled) {
    this(new V1UserInfo(), validationEnabled);
  }
  public V1UserInfoBuilder(V1UserInfoFluent<?> fluent) {
    this(fluent, false);
  }
  public V1UserInfoBuilder(V1UserInfoFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new V1UserInfo(), validationEnabled);
  }
  public V1UserInfoBuilder(V1UserInfoFluent<?> fluent,V1UserInfo instance) {
    this(fluent, instance, false);
  }
  public V1UserInfoBuilder(V1UserInfoFluent<?> fluent,V1UserInfo instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withExtra(instance.getExtra());

    fluent.withGroups(instance.getGroups());

    fluent.withUid(instance.getUid());

    fluent.withUsername(instance.getUsername());

    this.validationEnabled = validationEnabled; 
  }
  public V1UserInfoBuilder(V1UserInfo instance) {
    this(instance,false);
  }
  public V1UserInfoBuilder(V1UserInfo instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withExtra(instance.getExtra());

    this.withGroups(instance.getGroups());

    this.withUid(instance.getUid());

    this.withUsername(instance.getUsername());

    this.validationEnabled = validationEnabled; 
  }
  V1UserInfoFluent<?> fluent;
  Boolean validationEnabled;
  public V1UserInfo build() {
    V1UserInfo buildable = new V1UserInfo();
    buildable.setExtra(fluent.getExtra());
    buildable.setGroups(fluent.getGroups());
    buildable.setUid(fluent.getUid());
    buildable.setUsername(fluent.getUsername());
    return buildable;
  }
  
}
